import { Spec, SpecType } from 'pretur.spec';
import { Resolver, UnitializedResolver } from './resolver';
import { Synchronizer, UnitializedSynchronizer } from './synchronizer';
import { UninitializedSequelizeModel, SequelizeModel } from './sequelizeModel';
import { Pool } from './pool';
export declare type AliasModelMap<T extends SpecType> = {
    [P in keyof T['records'] | keyof T['sets']]: string;
};
export declare type AliasKeyMap<T extends SpecType> = {
    [P in keyof T['records'] | keyof T['sets']]: keyof T['fields'];
};
export interface ModelDescriptor<T extends SpecType> {
    spec: Spec<T>;
    name: string;
    primaryKeys: (keyof T['fields'])[];
    sequelizeModel?: SequelizeModel<T>;
    resolver?: Resolver<T>;
    synchronizer?: Synchronizer<T>;
    aliasModelMap: AliasModelMap<T>;
    aliasKeyMap: AliasKeyMap<T>;
    allowedAttributes: (keyof T['fields'])[];
    mutableAttributes: (keyof T['fields'])[];
    defaultOrder: [keyof T['fields'], 'ASC' | 'DESC'];
    sanitizeAttributes(attributes?: (keyof T['fields'])[] | keyof T['fields']): (keyof T['fields'])[];
    initialize(pool: Pool): void;
}
export interface BuildModelDescriptorOptions<T extends SpecType> {
    sequelizeModel?: UninitializedSequelizeModel<T>;
    resolver?: UnitializedResolver<T>;
    synchronizer?: UnitializedSynchronizer<T>;
    defaultOrder?: [keyof T['fields'], 'ASC' | 'DESC'];
    allowedAttributes?: (keyof T['fields'])[];
    allowedMutableAttributes?: (keyof T['fields'])[];
}
export declare function buildModelDescriptor<T extends SpecType>(spec: Spec<T>, options?: BuildModelDescriptorOptions<T>): ModelDescriptor<T>;
